@@ -58,4 +58,4 @@
 #' x <- sapply(1:3, function(i) rnorm(50))
 #' vc <- vine(x, copula_controls = list(family_set = "par"))
 #' summary(vc)
-NULL
+"_PACKAGE"
