@@ -106,6 +106,7 @@ vine <- function(data,
                    selcrit = "aic",
                    psi0 = 0.9,
                    presel = TRUE,
+                   allow_rotations = TRUE,
                    trunc_lvl = Inf,
                    tree_crit = "tau",
                    threshold = 0,
@@ -124,8 +125,9 @@ vine <- function(data,
   var_types[sapply(data, is.ordered)] <- "d"
 
   assert_that(is.list(margins_controls))
-  allowed_margins_controls <- c("mult", "xmin", "xmax", "bw", "deg")
+  allowed_margins_controls <- c("xmin", "xmax", "type", "mult", "bw", "deg")
   assert_that(in_set(names(margins_controls), allowed_margins_controls))
+
   assert_that(is.list(copula_controls))
   if (is.null(copula_controls$keep_data)) {
     copula_controls$keep_data <- TRUE
@@ -134,15 +136,19 @@ vine <- function(data,
 
   ## expand the required arguments and compute default mult if needed
   margins_controls <- expand_margin_controls(margins_controls, d, data)
-  check_margin_controls(data, margins_controls)
+  for (k in which(sapply(data, is.ordered))) {
+    margins_controls$type[k] <- "d"
+    margins_controls$xmin[k] <- 0
+    margins_controls$xmax[k] <- nlevels(data[[k]]) - 1
+  }
 
   ## estimation of the marginals
   vine <- list()
   vine$margins <- fit_margins_cpp(prep_for_margins(data),
-                                  sapply(data, nlevels),
-                                  mult = margins_controls$mult,
                                   xmin = margins_controls$xmin,
                                   xmax = margins_controls$xmax,
+                                  type = margins_controls$type,
+                                  mult = margins_controls$mult,
                                   bw = margins_controls$bw,
                                   deg = margins_controls$deg,
                                   weights = weights,
@@ -152,7 +158,7 @@ vine <- function(data,
 
   ## estimation of the R-vine copula --------------
   copula_controls$data <- compute_pseudo_obs(data, vine)
-  copula_controls$var_types <- var_types
+  copula_controls$var_types <- simplify_var_types(margins_controls$type)
   copula_controls$weights <- weights
   vine$copula <- do.call(vinecop, copula_controls)
   vine$copula_controls <- copula_controls[-which(names(copula_controls) == "data")]
@@ -227,10 +233,10 @@ vine_dist <- function(margins, pair_copulas, structure) {
   stopifnot(is.list(margins))
   if (depth(margins) == 1) {
     check_marg <- check_distr(margins)
-    npars_marg <- ncol(matrix) * get_npars_distr(margins)
+    try(npars_marg <- ncol(matrix) * get_npars_distr(margins), silent = TRUE)
   } else {
     check_marg <- lapply(margins, check_distr)
-    npars_marg <- sum(sapply(margins, get_npars_distr))
+    try(npars_marg <- sum(sapply(margins, get_npars_distr)), silent = TRUE)
   }
   is_ok <- sapply(check_marg, isTRUE)
   if (!all(is_ok)) {
@@ -255,7 +261,8 @@ vine_dist <- function(margins, pair_copulas, structure) {
 }
 
 expand_margin_controls <- function(controls, d, data) {
-  default_controls <- list(mult = NULL, xmin = NaN, xmax = NaN, bw = NA, deg = 2)
+  default_controls <-
+    list(xmin = NaN, xmax = NaN, type = "c", mult = NULL, bw = NA, deg = 2)
   controls <- modifyList(default_controls, controls)
   if (is.null(controls[["mult"]])) {
     controls[["mult"]] <- log(1 + d)
@@ -306,3 +313,9 @@ finalize_vine <- function(vine, data, weights, keep_data) {
   ## create and return object
   structure(vine, class = c("vine", "vine_dist"))
 }
+
+simplify_var_types <- function(x) {
+  x[x %in% c("cont", "continuous")] <- "c"
+  x[x %in% c("disc", "discrete", "zinf", "zero-inflated")] <- "d"
+  x
+}
