@@ -256,7 +256,7 @@ logLik.vinecop <- function(object, ...) {
 #' @references Nagler, T., Bumann, C., Czado, C. (2019). Model selection for
 #'   sparse high-dimensional vine copulas with application to portfolio risk.
 #'   *Journal of Multivariate Analysis, in press*
-#'   (\url{https://arxiv.org/pdf/1801.09739.pdf})
+#'   (\url{http://arxiv.org/pdf/1801.09739})
 #'
 #' @export mBICV
 #' @examples
@@ -306,10 +306,13 @@ summary.vinecop <- function(object, trees = seq_len(dim(object)["trunc_lvl"]), .
       k <- k + 1
     }
   }
-
+  if (length(object$names) != 0) {
+    attr(mdf, "var_names") <- object$names
+  }
   mdf
 }
 
+
 #' @export
 dim.vinecop_dist <- function(x) {
   dim(x$structure)
